# Changelog

## [stormi-v0.1.0-beta.2](https://github.com/pinellolab/stormi/compare/stormi-v0.1.0-beta.1...stormi-v0.1.0-beta.2) (2025-03-19)

### Bug Fixes

* **pyproject:** `0.1.0` -> `0.1.1` ([a8725be](https://github.com/pinellolab/stormi/commit/a8725be3c58ca3ff311c261e272a41e786d412e2))
